function Create(self)
	self.attached = false;
	self.attachActor = nil;
	
	self.frameTimer = Timer();
	self.frameDuration = 25;
	
	self.infectionTimer = Timer();
	self.infectionLength = 15000 / self.Sharpness;
	
	--The plant.
	self.plant = nil;
	self.headPos = nil;
	self.spored = false;
end

function Update(self)
	self.RotAngle = 0;
	self.AngularVel = 0;

	--If this hasn't become attached yet, don't play the animation.
	if self.attached == false then
		--Try to find something to latch onto.
		local moid = SceneMan:CastMORay(self.Pos, self.Vel * 2, -1, 0, false, 0);
		if moid ~= 255 then
			local mo = MovableMan:GetMOFromID(moid);
			local actor = MovableMan:GetMOFromID(mo.RootID);
			if actor:IsActor() then
				actor = ToActor(actor);
				--Only infect something living.
				if actor:IsDead() == false then
					--Infect the actor.
					self.attachActor = actor;
					self.attached = true;
					self.frameTimer:Reset();
					self.infectionTimer:Reset();
					
					--Find the highest point on the map, and send the actor there.
					local highestPoint = Vector(0,SceneMan.SceneHeight);
					for i=0, SceneMan.SceneWidth, 48 do
						local point = SceneMan:MovePointToGround(Vector(i,0), 0, 24);
						if point.Y < highestPoint.Y then
							highestPoint = point;
						end
					end
					
					self.attachActor.AIMode = Actor.AIMODE_GOTO;
					self.attachActor:AddAISceneWaypoint(highestPoint);
				end
			end
		end
		
		--If terrain was hit, die.
		if SceneMan:CastStrengthRay(self.Pos, self.Vel * 2, 0, Vector(), 0, 0, true) == true or (self.Vel.Magnitude < 0.5 and self.Age > 50) then
			self.attached = true;
			self.frameTimer:Reset();
		end
	else
		--Animate.
		if self.frameTimer:IsPastSimMS(self.frameDuration) then
			self.Frame = self.Frame + 1;
			if self.Frame > self.FrameCount - 1 then
				self.Frame = self.FrameCount - 1;
			end
			self.frameTimer:Reset();
		end
	
		--Stay on the actor.
		if MovableMan:ValidMO(self.attachActor) then
			self.Pos = self.attachActor.Pos;
			
			--Constantly make it unusable.
			self.attachActor:SetControllerMode(Controller.CIM_AI, -1);
			self.attachActor.AIMode = Actor.AIMODE_GOTO;
			
			--Once the timer is up, make the plant.
			if self.infectionTimer:IsPastSimMS(self.infectionLength) then
				--Wait until the actor is still.
				if self.plant == nil then
					if self.attachActor.Vel.Magnitude < 2 then
						self.plant = CreateMOSRotating("Infector Plant");
						MovableMan:AddParticle(self.plant);
					end
				else
					if self.headPos == nil then
						--Gib the actor's head.
						for i = 1, MovableMan:GetMOIDCount() - 1 do
							local mo = MovableMan:GetMOFromID(i);
							if mo.RootID == self.attachActor.ID and string.find(mo.PresetName,"Head") ~= nil then
								local att = ToAttachable(mo);
								local jOffset = Vector(att.JointOffset.X, att.JointOffset.Y);
								self.headPos = att.Pos + jOffset:RadRotate(att.RotAngle);
								self.attachActor.PinStrength = 10000;
								att:GibThis();
								break;
							end
						end
					end

					if self.headPos == nil then
						self.plant.Pos = Vector(self.attachActor.Pos.X, self.attachActor.Pos.Y);
					else
						self.plant.Pos = self.headPos;
					end
					self.plant.RotAngle = self.attachActor.RotAngle;
					
					if self.spored == false then
						--Spawn more spores.
						for i=0, 25 do
							local spore = CreateMOSRotating("Infector Spore");
							spore.Pos = self.plant.Pos;
							local vel = Vector(math.random(-20,20),-math.random(10,20));
							spore.Vel = vel:RadRotate(self.attachActor.RotAngle);
							spore.Sharpness = self.Sharpness + 1;
							MovableMan:AddParticle(spore);
						end
						
						self.spored = true;
					end

					--Don't let the actor settle until the plant has finished sprouting.
					if self.plant.Frame ~= self.plant.FrameCount - 1 then
						self.attachActor.ToSettle = false;
						self.attachActor.AngularVel = 0;
					else
						self.attachActor.ToSettle = true;
						self.attachActor.PinStrength = 0;
						self.attachActor.Health = 0;
						self.plant.ToSettle = true;
						self.ToDelete = true;
					end
				end
			end
		else
			--If the animation has ended and the actor isn't present, remove this.
			if self.Frame == self.FrameCount - 1 then
				self.ToDelete = true;
			end
		end
	end
end